@@ -5,5 +5,5 @@ def joke():
     return (u'Wenn ist das Nunst\u00fcck git und Slotermeyer? Ja! ... '
             u'Beiherhund das Oder die Flipperwaldt gersput.')
 
-if __name__ == "__main__":
-    print "Decide what to do"
\ No newline at end of file
+def main():
+    print 'Initialize device manager ...'
\ No newline at end of file
